@@ -29,6 +29,7 @@ extern "C" {
 #include <cpp11/protect.hpp>
 #include <string>
 #include <cstring>
+#include <cstdint>
 #include <iomanip>
 #include <sstream>
 #include <memory>
@@ -232,7 +233,7 @@ inline void write_attr_str(SvgStreamPtr stream, const char* attr, const char* va
 
 // Writing clip path attribute
 inline void write_attr_clip(SvgStreamPtr stream, std::string clipid) {
-  if (!clipid.size())
+  if (clipid.empty())
     return;
 
   (*stream) << " clip-path='url(#cp" << clipid << ")'";
